@@ -1,14 +1,14 @@
 package Bencher::Scenario::MojoDOM::Parsing;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-04-12'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Bencher::ScenarioUtil::MojoDOM;
-use PERLANCAR::HTML::Tree::Examples qw(gen_sample_html);
+use PERLANCAR::HTML::Tree::Examples qw(gen_sample_data);
 
 our $scenario = {
     summary => 'Benchmark parsing of HTML',
@@ -20,7 +20,7 @@ _
     before_gen_items => sub {
         # prepare html
         %main::htmls = map {
-            ($_->{name} => gen_sample_html(size => $_->{name}))
+            ($_->{name} => gen_sample_data(size => $_->{name}))
         } @Bencher::ScenarioUtil::MojoDOM::datasets;
     },
     participants => [
@@ -48,7 +48,7 @@ Bencher::Scenario::MojoDOM::Parsing - Benchmark parsing of HTML
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::MojoDOM::Parsing (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-01.
+This document describes version 0.003 of Bencher::Scenario::MojoDOM::Parsing (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-12.
 
 =head1 SYNOPSIS
 
@@ -88,27 +88,27 @@ Function call template:
 
 =item * small1
 
-16 elements, 4 levels,  bytes
+16 elements, 4 levels
 
 =item * medium1
 
-20k elements, 7 levels,  bytes
+20k elements, 7 levels
 
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m MojoDOM::Parsing >>):
 
  +---------+----------------+-----------+-----------+------------+------------------+---------+---------+
  | dataset | arg_expr       | rate (/s) | time (ms) | vs_slowest | result_size (MB) | errors  | samples |
  +---------+----------------+-----------+-----------+------------+------------------+---------+---------+
- | medium1 | h4:first-child | 1.07      | 930       | 1          | 24.3             | 0.00016 | 20      |
- | medium1 | h4             | 1.08      | 929       | 1          | 24.3             | 0.00021 | 23      |
- | small1  | h4             | 1.38e+03  | 0.724     | 1.29e+03   | 0.0194           | 4.8e-07 | 20      |
- | small1  | h4:first-child | 1.39e+03  | 0.721     | 1.29e+03   | 0.0194           | 2.1e-07 | 21      |
+ | medium1 | h4:first-child | 2.78      | 360       | 1          | 24.3             | 0.00025 | 20      |
+ | medium1 | h4             | 2.8       | 3.6e+02   | 1          | 24               | 0.00042 | 21      |
+ | small1  | h4             | 3.6e+03   | 0.27      | 1.3e+03    | 0.019            | 4.1e-07 | 22      |
+ | small1  | h4:first-child | 3.67e+03  | 0.272     | 1.32e+03   | 0.0194           | 2e-07   | 22      |
  +---------+----------------+-----------+-----------+------------+------------------+---------+---------+
 
 
@@ -117,8 +117,8 @@ Benchmark module startup overhead (C<< bencher -m MojoDOM::Parsing --module-star
  +---------------------+-----------+------------------------+------------+---------+---------+
  | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +---------------------+-----------+------------------------+------------+---------+---------+
- | Mojo::DOM           | 1e+02     | 80                     | 1          | 0.0028  | 20      |
- | perl -e1 (baseline) | 2e+01     | 0                      | 7          | 0.00033 | 20      |
+ | Mojo::DOM           | 36        | 31.5                   | 1          | 0.00016 | 20      |
+ | perl -e1 (baseline) | 4.5       | 0                      | 8          | 4.1e-05 | 20      |
  +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
