@@ -1,11 +1,11 @@
 package Bencher::ScenarioUtil::MojoDOM;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-04-12'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 our @datasets = (
-    {name => 'small1' , summary => '16 elements, 4 levels, '.length($htmls{small1}).' bytes' , args=>{size=>'small1' }},
-    {name => 'medium1', summary => '20k elements, 7 levels, '.length($htmls{medium1}).' bytes', args=>{size=>'medium1'}},
+    {name => 'small1' , summary => '16 elements, 4 levels' , args=>{size=>'small1' }},
+    {name => 'medium1', summary => '20k elements, 7 levels', args=>{size=>'medium1'}},
 );
 
 # we want to record the version of these modules too in the benchmark result
@@ -29,7 +29,7 @@ Bencher::ScenarioUtil::MojoDOM - Utility routines
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::ScenarioUtil::MojoDOM (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-01.
+This document describes version 0.003 of Bencher::ScenarioUtil::MojoDOM (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-12.
 
 =head1 HOMEPAGE
 
